@@ -17,36 +17,42 @@
 Store metadata and options.
 """
 
+import importlib.resources
 import os
 import re
 import urllib.parse
 import shutil
 import socket
-import _LinkChecker_configdata as configdata
-from .. import log, LOG_CHECK, get_install_data, fileutil
-from . import confparse
-from xdg.BaseDirectory import xdg_config_home, xdg_data_home
 
-Version = configdata.version
-ReleaseDate = configdata.release_date
-AppName = configdata.name
+from .. import log, LOG_CHECK, PACKAGE_NAME, fileutil
+from . import confparse
+
+try:
+    from .. import _release
+except ImportError:
+    raise SystemExit('Run "hatchling build --hooks-only" first')
+
+Version = _release.__version__
+ReleaseDate = _release.__release_date__
+CopyrightYear = _release.__copyright_year__
+AppName = _release.__app_name__
 App = AppName + " " + Version
-Author = configdata.author
+Author = _release.__author__
 HtmlAuthor = Author.replace(' ', '&nbsp;')
-Copyright = "Copyright (C) 2000-2016 Bastian Kleineidam, 2010-2021 " + Author
-HtmlCopyright = ("Copyright &copy; 2000-2016 Bastian&nbsp;Kleineidam, 2010-2021 "
-                 + HtmlAuthor)
+Copyright = f"Copyright (C) 2000-2016 Bastian Kleineidam, 2010-{CopyrightYear} {Author}"
+HtmlCopyright = (
+    "Copyright &copy; 2000-2016 Bastian&nbsp;Kleineidam, "
+    f"2010-{CopyrightYear} {HtmlAuthor}")
 HtmlAppInfo = App + ", " + HtmlCopyright
-Url = configdata.url
-SupportUrl = "https://github.com/linkchecker/linkchecker/issues"
-UserAgent = "Mozilla/5.0 (compatible; %s/%s; +%s)" % (AppName, Version, Url)
+Url = _release.__url__
+SupportUrl = _release.__support_url__
+UserAgent = f"Mozilla/5.0 (compatible; {AppName}/{Version}; +{Url})"
 Freeware = (
     AppName
     + """ comes with ABSOLUTELY NO WARRANTY!
 This is free software, and you are welcome to redistribute it under
-certain conditions. Look at the file `LICENSE' within this distribution."""
+certain conditions. Look at the file `COPYING' within this distribution."""
 )
-Portable = configdata.portable
 
 
 def normpath(path):
@@ -62,13 +68,11 @@ Modules = (
     ("bs4", "Beautiful Soup", "__version__"),
     ("dns.version", "dnspython", "version"),
     ("requests", "Requests", "__version__"),
-    ("xdg", "PyXDG", "__version__"),
     # optional modules
     ("argcomplete", "Argcomplete", None),
     ("GeoIP", "GeoIP", 'lib_version'),  # on Unix systems
     ("pygeoip", "GeoIP", 'lib_version'),  # on Windows systems
-    ("sqlite3", "Pysqlite", 'version'),
-    ("sqlite3", "Sqlite", 'sqlite_version'),
+    ("sqlite3", "SQLite", 'sqlite_version'),
     ("meliae", "Meliae", '__version__'),
 )
 
@@ -77,12 +81,13 @@ def get_modules_info():
     """Return unicode string with detected module info."""
     module_infos = []
     for (mod, name, version_attr) in Modules:
-        if not fileutil.has_module(mod):
+        try:
+            module = importlib.import_module(mod)
+        except ModuleNotFoundError:
             continue
-        if version_attr and hasattr(mod, version_attr):
-            attr = getattr(mod, version_attr)
+        if version_attr and (attr := getattr(module, version_attr, None)):
             version = attr() if callable(attr) else attr
-            module_infos.append("%s %s" % (name, version))
+            module_infos.append(f"{name} {version}")
         else:
             # ignore attribute errors in case library developers
             # change the version information attribute
@@ -90,35 +95,6 @@ def get_modules_info():
     return "Modules: %s" % (", ".join(module_infos))
 
 
-def get_share_dir():
-    """Return absolute path of LinkChecker example configuration."""
-    return os.path.join(get_install_data(), "share", "linkchecker")
-
-
-def get_share_file(filename, devel_dir=None):
-    """Return a filename in the share directory.
-
-    @param devel_dir: directory to search when developing
-    @type devel_dir: string
-    @param filename: filename to search for
-    @type filename: string
-    @return: the found filename or None
-    @rtype: string
-    @raises: ValueError if not found
-    """
-    paths = [get_share_dir()]
-    if devel_dir is not None:
-        # when developing
-        paths.insert(0, devel_dir)
-    for path in paths:
-        fullpath = os.path.join(path, filename)
-        if os.path.isfile(fullpath):
-            return fullpath
-    # not found
-    msg = "%s not found in %s; check your installation" % (filename, paths)
-    raise ValueError(msg)
-
-
 def get_system_cert_file():
     """Try to find a system-wide SSL certificate file.
     @return: the filename to the cert file
@@ -173,7 +149,6 @@ class Configuration(dict):
         self["maxrunseconds"] = None
         self["maxrequestspersecond"] = 10
         self["maxhttpredirects"] = 10
-        self["nntpserver"] = os.environ.get("NNTP_SERVER", None)
         self["sslverify"] = True
         self["threads"] = 10
         self["timeout"] = 60
@@ -189,6 +164,7 @@ class Configuration(dict):
         self["loginextrafields"] = {}
         # filtering
         self["externlinks"] = []
+        self["ignoreerrors"] = []
         self["ignorewarnings"] = []
         self["internlinks"] = []
         self["checkextern"] = False
@@ -327,8 +303,7 @@ class Configuration(dict):
 
     def sanitize_ssl(self):
         """Use local installed certificate file if available.
-        Tries to get system, then certifi, then the own
-        installed certificate file."""
+        Tries to get system, then certifi certificate file."""
         if self["sslverify"] is True:
             try:
                 self["sslverify"] = get_system_cert_file()
@@ -336,35 +311,37 @@ class Configuration(dict):
                 try:
                     self["sslverify"] = get_certifi_file()
                 except (ValueError, ImportError):
-                    try:
-                        self["sslverify"] = get_share_file('cacert.pem')
-                    except ValueError:
-                        pass
+                    pass
 
 
 def get_user_data():
     """Get the user data folder.
-    Returns "~/.linkchecker/" if this folder exists, \
-    "$XDG_DATA_HOME/linkchecker" if it does not.
+    Returns "~/.linkchecker/" if this folder exists,
+    "$XDG_DATA_HOME/linkchecker" if $XDG_DATA_HOME is set,
+    else "~/.local/share/linkchecker".
     @rtype string
     """
     homedotdir = normpath("~/.linkchecker/")
     userdata = (
         homedotdir
         if os.path.isdir(homedotdir)
-        else os.path.join(xdg_data_home, "linkchecker")
+        else os.path.join(
+            os.environ.get("XDG_DATA_HOME") or os.path.expanduser(
+                os.path.join("~", ".local", "share")),
+            "linkchecker")
     )
     return userdata
 
 
 def get_plugin_folders():
     """Get linkchecker plugin folders. Default is
-    "$XDG_DATA_HOME/linkchecker/plugins/". "~/.linkchecker/plugins/" is also
-    supported for backwards compatibility, and is used if both directories
-    exist."""
+    "$XDG_DATA_HOME/linkchecker/plugins/" if $XDG_DATA_HOME is set, else
+    "~/.local/share/linkchecker/plugins/".
+    "~/.linkchecker/plugins/" is also
+    supported for backwards compatibility, and is used if it exists."""
     folders = []
     defaultfolder = os.path.join(get_user_data(), "plugins")
-    if not os.path.exists(defaultfolder) and not Portable:
+    if not os.path.exists(defaultfolder):
         try:
             make_userdir(defaultfolder)
         except Exception as errmsg:
@@ -390,33 +367,37 @@ def make_userdir(child):
 def get_user_config():
     """Get the user configuration filename.
     If the user configuration file does not exist, copy it from the initial
-    configuration file, but only if this is not a portable installation.
+    configuration file.
     Returns path to user config file (which might not exist due to copy
-    failures or on portable systems).
+    failures).
     @return configuration filename
     @rtype string
     """
-    # initial config (with all options explained)
-    initialconf = normpath(os.path.join(get_share_dir(), "linkcheckerrc"))
     # per user config settings
     homedotfile = normpath("~/.linkchecker/linkcheckerrc")
     userconf = (
         homedotfile
         if os.path.isfile(homedotfile)
-        else os.path.join(xdg_config_home, "linkchecker", "linkcheckerrc")
+        else os.path.join(
+            os.environ.get("XDG_CONFIG_HOME") or os.path.expanduser(
+                os.path.join("~", ".config")),
+            "linkchecker", "linkcheckerrc")
     )
-    if os.path.isfile(initialconf) and not os.path.exists(userconf) and not Portable:
-        # copy the initial configuration to the user configuration
-        try:
-            make_userdir(userconf)
-            shutil.copy(initialconf, userconf)
-        except Exception as errmsg:
-            msg = _(
-                "could not copy initial configuration file %(src)r"
-                " to %(dst)r: %(errmsg)r"
-            )
-            args = dict(src=initialconf, dst=userconf, errmsg=errmsg)
-            log.warn(LOG_CHECK, msg % args)
+    if not os.path.exists(userconf):
+        # initial config (with all options explained)
+        with importlib.resources.path(
+                f"{PACKAGE_NAME}.data", "linkcheckerrc") as initialconf:
+            # copy the initial configuration to the user configuration
+            try:
+                make_userdir(userconf)
+                shutil.copy(initialconf, userconf)
+            except Exception as errmsg:
+                msg = _(
+                    "could not copy initial configuration file %(src)r"
+                    " to %(dst)r: %(errmsg)r"
+                )
+                args = dict(src=initialconf, dst=userconf, errmsg=errmsg)
+                log.warn(LOG_CHECK, msg % args)
     return userconf
 
 
